@@ -163,7 +163,11 @@ P_batch.add_argument('-p', '--processes',
                 parallel. Without an argument, use the maximum number of
                 available CPUs. [Default: process each BAM in serial]""")
 P_batch.add_argument("--rlibpath", metavar="DIRECTORY",
-        help="Path to an alternative site-library to use for R packages.")
+        help=argparse.SUPPRESS)
+P_batch.add_argument("--rscript-path", metavar="PATH", default="Rscript",
+        help="""Path to the Rscript excecutable to use for running R code.
+                Use this option to specify a non-default R installation.
+                [Default: %(default)s]""")
 
 # Reference-building options
 P_batch_newref = P_batch.add_argument_group(
@@ -401,20 +405,25 @@ P_autobin.add_argument('-g', '--access', metavar="FILENAME",
 P_autobin.add_argument('-t', '--targets',
         help="""Potentially targeted genomic regions, e.g. all possible exons
                 for the reference genome. Format: BED, interval list, etc.""")
-P_autobin.add_argument('-b', '--bp-per-bin', type=float, default=100000.,
+P_autobin.add_argument('-b', '--bp-per-bin',
+        type=float, default=100000.,
         help="""Desired average number of sequencing read bases mapped to each
                 bin. [Default: %(default)s]""")
 
-P_autobin.add_argument('--target-max-size', type=int, default=20000,
-        help="Maximum size of target bins.")
-P_autobin.add_argument('--target-min-size', type=int, default=20,
-        help="Minimum size of target bins.")
-P_autobin.add_argument('--antitarget-max-size', type=int, default=500000,
-        help="Maximum size of antitarget bins.")
-P_autobin.add_argument('--antitarget-min-size', type=int, default=500,
-        help="Minimum size of antitarget bins.")
+P_autobin.add_argument('--target-max-size', metavar="BASES",
+        type=int, default=20000,
+        help="Maximum size of target bins. [Default: %(default)s]")
+P_autobin.add_argument('--target-min-size', metavar="BASES",
+        type=int, default=20,
+        help="Minimum size of target bins. [Default: %(default)s]")
+P_autobin.add_argument('--antitarget-max-size', metavar="BASES",
+        type=int, default=500000,
+        help="Maximum size of antitarget bins. [Default: %(default)s]")
+P_autobin.add_argument('--antitarget-min-size', metavar="BASES",
+        type=int, default=500,
+        help="Minimum size of antitarget bins. [Default: %(default)s]")
 
-P_autobin.add_argument('--annotate',
+P_autobin.add_argument('--annotate', metavar="FILENAME",
         help="""Use gene models from this file to assign names to the target
                 regions. Format: UCSC refFlat.txt or ensFlat.txt file
                 (preferred), or BED, interval list, GFF, or similar.""")
@@ -616,6 +625,7 @@ def _cmd_segment(args):
                                            skip_outliers=args.drop_outliers,
                                            save_dataframe=bool(args.dataframe),
                                            rlibpath=args.rlibpath,
+                                           rscript_path=args.rscript_path,
                                            processes=args.processes)
     if args.dataframe:
         segments, dframe = results
@@ -648,14 +658,18 @@ P_segment.add_argument('-t', '--threshold', type=float,
 P_segment.add_argument("--drop-low-coverage", action='store_true',
         help="""Drop very-low-coverage bins before segmentation to avoid
                 false-positive deletions in poor-quality tumor samples.""")
-P_segment.add_argument("--drop-outliers",
-        type=float, default=10, metavar="FACTOR",
+P_segment.add_argument("--drop-outliers", metavar="FACTOR",
+        type=float, default=10,
         help="""Drop outlier bins more than this many multiples of the 95th
                 quantile away from the average within a rolling window.
                 Set to 0 for no outlier filtering.
                 [Default: %(default)g]""")
 P_segment.add_argument("--rlibpath", metavar="DIRECTORY",
-        help="Path to an alternative site-library to use for R packages.")
+        help=argparse.SUPPRESS)
+P_segment.add_argument("--rscript-path", metavar="PATH", default="Rscript",
+        help="""Path to the Rscript excecutable to use for running R code.
+                Use this option to specify a non-default R installation.
+                [Default: %(default)s]""")
 P_segment.add_argument('-p', '--processes',
         nargs='?', type=int, const=0, default=1,
         help="""Number of subprocesses to segment in parallel.
@@ -701,7 +715,8 @@ def _cmd_call(args):
         logging.info("Shifting log2 values by %f", -args.center_at)
         cnarr['log2'] -= args.center_at
     elif args.center:
-        cnarr.center_all(args.center, verbose=True)
+        cnarr.center_all(args.center, skip_low=args.drop_low_coverage,
+                verbose=True)
 
     varr = load_het_snps(args.vcf, args.sample_id, args.normal_id,
                          args.min_variant_depth, args.zygosity_freq)
@@ -747,6 +762,9 @@ P_call.add_argument("--ploidy", type=int, default=2,
         help="Ploidy of the sample cells. [Default: %(default)d]")
 P_call.add_argument("--purity", type=float,
         help="Estimated tumor cell fraction, a.k.a. purity or cellularity.")
+P_call.add_argument("--drop-low-coverage", action='store_true',
+        help="""Drop very-low-coverage bins before segmentation to avoid
+                false-positive deletions in poor-quality tumor samples.""")
 P_call.add_argument('-x', '--sample-sex', '-g', '--gender', dest='sample_sex',
         choices=('m', 'y', 'male', 'Male', 'f', 'x', 'female', 'Female'),
         help="""Specify the sample's chromosomal sex as male or female.
@@ -1176,8 +1194,8 @@ def do_sex(cnarrs, is_male_reference):
         is_xy, stats = cna.compare_sex_chromosomes(is_male_reference)
         return (cna.meta["filename"] or cna.sample_id,
                 "Male" if is_xy else "Female",
-                strsign(stats['chrx_ratio']),
-                strsign(stats['chry_ratio']))
+                strsign(stats['chrx_ratio']) if stats else "NA",
+                strsign(stats['chry_ratio']) if stats else "NA")
 
     rows = (guess_and_format(cna) for cna in cnarrs)
     columns = ["sample", "sex", "X_logratio", "Y_logratio"]
@@ -1440,7 +1458,7 @@ def _cmd_import_rna(args):
     """Convert a cohort of per-gene log2 ratios to CNVkit .cnr format."""
     all_data, cnrs = import_rna.do_import_rna(
         args.gene_counts, args.format, args.gene_resource, args.correlations,
-        args.normal)
+        args.normal, args.do_gc, args.do_txlen, args.max_log2)
     logging.info("Writing output files")
     if args.output:
         all_data.to_csv(args.output, sep='\t', index=True)
@@ -1469,8 +1487,11 @@ P_import_rna.add_argument('-g', '--gene-resource',
         help="Location of gene info table from Ensembl BioMart.")
 P_import_rna.add_argument('-c', '--correlations', metavar="FILE",
         help="""Correlation of each gene's copy number with
-        expression. Output of cnv_expression_correlate.py.""")
-P_import_rna.add_argument('-n', '--normal', nargs='+',
+                expression. Output of cnv_expression_correlate.py.""")
+P_import_rna.add_argument('--max-log2', metavar="FLOAT", default=3.0,
+        help="""Maximum log2 value in output. Observed values above this limit
+                will be replaced with this value.""")
+P_import_rna.add_argument('-n', '--normal', nargs='+', default=[],
         help="""Normal samples (same format as `gene_counts`) to be used as a
                 control to when normalizing and re-centering gene read depth
                 ratios. All filenames following this option will be used.""")
@@ -1480,6 +1501,14 @@ P_import_rna.add_argument('-d', '--output-dir',
                 sample. [Default: %(default)s]""")
 P_import_rna.add_argument('-o', '--output', metavar="FILE",
         help="Output file name (summary table).")
+
+P_import_rna_bias = P_import_rna.add_argument_group(
+    "To disable specific automatic bias corrections")
+P_import_rna_bias.add_argument('--no-gc', dest='do_gc', action='store_false',
+        help="Skip GC correction.")
+P_import_rna_bias.add_argument('--no-txlen', dest='do_txlen', action='store_false',
+        help="Skip transcript length correction.")
+
 P_import_rna.set_defaults(func=_cmd_import_rna)
 
 
@@ -1504,10 +1533,15 @@ def _cmd_export_bed(args):
         # ENH: args.sample_sex as a comma-separated list
         is_sample_female = verify_sample_sex(segments, args.sample_sex,
                                              args.male_reference)
+        if args.sample_id:
+            label = args.sample_id
+        elif args.label_genes:
+            label = None
+        else:
+            label = segments.sample_id
         tbl = export.export_bed(segments, args.ploidy,
                                 args.male_reference, is_sample_female,
-                                args.sample_id or segments.sample_id,
-                                args.show)
+                                label, args.show)
         bed_tables.append(tbl)
     table = pd.concat(bed_tables)
     write_dataframe(args.output, table, header=False)
@@ -1520,6 +1554,9 @@ P_export_bed.add_argument('segments', nargs='+',
 P_export_bed.add_argument("-i", "--sample-id", metavar="LABEL",
         help="""Identifier to write in the 4th column of the BED file.
                 [Default: use the sample ID, taken from the file name]""")
+P_export_bed.add_argument('--label-genes', action='store_true',
+        help="""Show gene names in the 4th column of the BED file.
+        (This is a bad idea if >1 input files are given.)""")
 P_export_bed.add_argument("--ploidy", type=int, default=2,
         help="Ploidy of the sample cells. [Default: %(default)d]")
 P_export_bed.add_argument('-x', '--sample-sex', '-g', '--gender',
