@@ -11,7 +11,7 @@ import numpy as np
 import pandas as pd
 
 from .chromsort import sorter_chrom
-from .intersect import by_ranges, into_ranges, iter_ranges
+from .intersect import by_ranges, into_ranges, iter_ranges, iter_slices
 from .merge import flatten, merge
 from .rangelabel import to_label
 from .subtract import subtract
@@ -275,7 +275,7 @@ class GenomicArray(object):
         for chrom, subtable in self.data.groupby("chromosome", sort=False):
             yield chrom, self.as_dataframe(subtable)
 
-    def by_ranges(self, other, mode='inner', keep_empty=True):
+    def by_ranges(self, other, mode='outer', keep_empty=True):
         """Group rows by another GenomicArray's bin coordinate ranges.
 
         For example, this can be used to group SNVs by CNV segments.
@@ -336,7 +336,7 @@ class GenomicArray(object):
     def labels(self):
         return self.data.apply(to_label, axis=1)
 
-    def in_range(self, chrom=None, start=None, end=None, mode='inner'):
+    def in_range(self, chrom=None, start=None, end=None, mode='outer'):
         """Get the GenomicArray portion within the given genomic range.
 
         Parameters
@@ -368,7 +368,7 @@ class GenomicArray(object):
         results = iter_ranges(self.data, chrom, start, end, mode)
         return self.as_dataframe(next(results))
 
-    def in_ranges(self, chrom=None, starts=None, ends=None, mode='inner'):
+    def in_ranges(self, chrom=None, starts=None, ends=None, mode='outer'):
         """Get the GenomicArray portion within the specified ranges.
 
         Similar to `in_ranges`, but concatenating the selections of all the
@@ -415,7 +415,8 @@ class GenomicArray(object):
         Parameters
         ----------
         other : GenomicArray
-            Bins to
+            Ranges into which the overlapping values of `self` will be
+            summarized.
         column : string
             Column name in `self` to extract values from.
         default
@@ -448,6 +449,43 @@ class GenomicArray(object):
             return pd.Series(np.repeat(default, len(other)))
         return into_ranges(self.data, other.data, column, default, summary_func)
 
+    def iter_ranges_of(self, other, column, mode='outer', keep_empty=True):
+        """Group rows by another GenomicArray's bin coordinate ranges.
+
+        For example, this can be used to group SNVs by CNV segments.
+
+        Bins in this array that fall outside the other array's bins are skipped.
+
+        Parameters
+        ----------
+        other : GenomicArray
+            Another GA instance.
+        column : string
+            Column name in `self` to extract values from.
+        mode : string
+            Determines what to do with bins that overlap a boundary of the
+            selection. Possible values are:
+
+            - ``inner``: Drop the bins on the selection boundary, don't emit them.
+            - ``outer``: Keep/emit those bins as they are.
+            - ``trim``: Emit those bins but alter their boundaries to match the
+              selection; the bin start or end position is replaced with the
+              selection boundary position.
+        keep_empty : bool
+            Whether to also yield `other` bins with no overlapping bins in
+            `self`, or to skip them when iterating.
+
+        Yields
+        ------
+        tuple
+            (other bin, GenomicArray of overlapping rows in self)
+        """
+        if column not in self.data.columns:
+            raise ValueError("No column named %r in this object" % column)
+        ser = self.data[column]
+        for slc in iter_slices(self.data, other.data, mode, keep_empty):
+            yield ser[slc]
+
     # Modification
 
     def add(self, other):
@@ -458,10 +496,9 @@ class GenomicArray(object):
         if not isinstance(other, self.__class__):
             raise ValueError("Argument (type %s) is not a %s instance"
                              % (type(other), self.__class__))
-        if not len(other.data):
-            return self.copy()
-        self.data = self.data.append(other.data, ignore_index=True)
-        self.sort()
+        if len(other.data):
+            self.data = self.data.append(other.data, ignore_index=True)
+            self.sort()
 
     def concat(self, others):
         """Concatenate several GenomicArrays, keeping this array's metadata.
@@ -582,6 +619,23 @@ class GenomicArray(object):
         return self.as_dataframe(flatten(self.data, combine=combine,
                                          split_columns=split_columns))
 
+    def intersection(self, other, mode='outer'):
+        """Select the bins in `self` that overlap the regions in `other`.
+
+        The extra fields of `self`, but not `other`, are retained in the output.
+        """
+        # TODO options for which extra fields to keep
+        #   by default, keep just the fields in 'table'
+        if mode == 'trim':
+            # Slower
+            chunks = [chunk.data for _, chunk in
+                      self.by_ranges(other, mode=mode, keep_empty=False)]
+            return self.as_dataframe(pd.concat(chunks))
+        else:
+            slices = iter_slices(self.data, other.data, mode, False)
+            indices = np.concatenate(list(slices))
+            return self.as_dataframe(self.data.loc[indices])
+
     def merge(self, bp=0, stranded=False, combine=None):
         """Merge adjacent or overlapping regions into single rows.
 
