@@ -7,11 +7,12 @@ GenomicArray types.
 
 """
 from __future__ import print_function, absolute_import, division
-from builtins import zip
+from builtins import range, zip
 from past.builtins import basestring
 
 import numpy as np
 import pandas as pd
+from pandas.core.index import Int64Index
 
 from .combiners import first_of, join_strings, make_const
 
@@ -32,13 +33,17 @@ def by_ranges(table, other, mode, keep_empty):
 
 
 def by_shared_chroms(table, other, keep_empty=True):
-    other_chroms = {c: o for c, o in other.groupby(['chromosome'], sort=False)}
-    for chrom, ctable in table.groupby(['chromosome'], sort=False):
-        if chrom in other_chroms:
-            otable = other_chroms[chrom]
-            yield chrom, ctable, otable
-        elif keep_empty:
-            yield chrom, ctable, None
+    if table['chromosome'].is_unique and other['chromosome'].is_unique:
+        yield table['chromosome'].iat[0], table, other
+        # yield None, table, other
+    else:
+        other_chroms = {c: o for c, o in other.groupby(['chromosome'], sort=False)}
+        for chrom, ctable in table.groupby(['chromosome'], sort=False):
+            if chrom in other_chroms:
+                otable = other_chroms[chrom]
+                yield chrom, ctable, otable
+            elif keep_empty:
+                yield chrom, ctable, None
 
 
 def into_ranges(source, dest, src_col, default, summary_func):
@@ -60,39 +65,30 @@ def into_ranges(source, dest, src_col, default, summary_func):
         summary_func = make_const(summary_func)
 
     def series2value(ser):
+        if len(ser) == 0:
+            return default
         if len(ser) == 1:
             return ser.iat[0]
         return summary_func(ser)
 
-    return pd.Series([(series2value(src_rows[src_col])
-                       if len(src_rows) else default)
-                      for _bin, src_rows in by_ranges(source, dest, 'outer',
-                                                      True)])
+    column = source[src_col]
+    result = [series2value(column[slc])
+              for slc in iter_slices(source, dest, 'outer', True)]
+    return pd.Series(result)
 
 
 def iter_ranges(table, chrom, starts, ends, mode):
     """Iterate through sub-ranges."""
     assert mode in ('inner', 'outer', 'trim')
-    # Optional if we've already subsetted by chromosome (not checked!)
     if chrom:
         assert isinstance(chrom, basestring)  # ENH: accept array?
         try:
             table = table[table['chromosome'] == chrom]
         except KeyError:
             raise KeyError("Chromosome %s is not in this probe set" % chrom)
-    # Edge cases
-    if not len(table) or (starts is None and ends is None):
-        yield table
-        raise StopIteration
-    # Don't be fooled by nested bins
-    if ((ends is not None and len(ends)) and
-        (starts is not None and len(starts))
-       ) and not _monotonic(table.end):
-        # At least one bin is fully nested -- account for it
-        irange_func = _irange_nested
-    else:
-        irange_func = _irange_simple
-    for region_idx, start_val, end_val in irange_func(table, starts, ends, mode):
+
+    for region_idx, start_val, end_val in idx_ranges(table, None, starts, ends,
+            'inner' if mode == 'inner' else 'outer'):
         subtable = table.iloc[region_idx]
         if mode == 'trim':
             subtable = subtable.copy()
@@ -105,6 +101,53 @@ def iter_ranges(table, chrom, starts, ends, mode):
         yield subtable
 
 
+def iter_slices(table, other, mode, keep_empty):
+    """Yields indices to extract ranges from `table`.
+
+    Returns an iterable of integer arrays that can apply to Series objects,
+    i.e. columns of `table`. These indices are of the DataFrame/Series' Index,
+    not array coordinates -- so be sure to use DataFrame.loc, Series.loc, or
+    Series getitem, as opposed to .iloc or indexing directly into Numpy arrays.
+    """
+    for _c, bin_rows, src_rows in by_shared_chroms(other, table, keep_empty):
+        if src_rows is None:
+            # Emit empty indices since 'table' is missing this chromosome
+            for _ in range(len(bin_rows)):
+                yield Int64Index([])
+        else:
+            for slc, _s, _e in idx_ranges(src_rows, None, bin_rows.start,
+                                          bin_rows.end, mode):
+                indices = src_rows.index[slc].values
+                if keep_empty or len(indices):
+                    yield indices
+
+
+def idx_ranges(table, chrom, starts, ends, mode):
+    """Iterate through sub-ranges."""
+    assert mode in ('inner', 'outer')
+    # Optional if we've already subsetted by chromosome (not checked!)
+    if chrom:
+        assert isinstance(chrom, basestring)  # ENH: accept array?
+        try:
+            table = table[table['chromosome'] == chrom]
+        except KeyError:
+            raise KeyError("Chromosome %s is not in this probe set" % chrom)
+    # Edge cases
+    if not len(table) or (starts is None and ends is None):
+        yield table.index, None, None
+    else:
+        # Don't be fooled by nested bins
+        if ((ends is not None and len(ends)) and
+            (starts is not None and len(starts))
+        ) and not _monotonic(table.end):
+            # At least one bin is fully nested -- account for it
+            irange_func = _irange_nested
+        else:
+            irange_func = _irange_simple
+        for region_idx, start_val, end_val in irange_func(table, starts, ends, mode):
+            yield region_idx, start_val, end_val
+
+
 def _irange_simple(table, starts, ends, mode):
     """Slice subsets of table when regions are not nested."""
     if starts is not None and len(starts):
